summaryrefslogtreecommitdiff
path: root/audio/sysvad/EndpointsCommon/speakerhptopo.cpp
diff options
context:
space:
mode:
authorDaniel Rugerio <[email protected]>2021-08-13 15:05:12 -0700
committerGitHub <[email protected]>2021-08-13 15:05:12 -0700
commit7895dd22785ddba5e973662ed942be3b3452b89d (patch)
tree5c4572d5bfd076d3776a88c5757e37f3ed50c0e7 /audio/sysvad/EndpointsCommon/speakerhptopo.cpp
parentdf47b2d284558fa9aacd19257153037e4ebba60e (diff)
audio: Updates for Windows 10 22000 (#655)
* Updates for Windows 10 22000. * Change how WIL is consumed.
Diffstat (limited to 'audio/sysvad/EndpointsCommon/speakerhptopo.cpp')
-rw-r--r--audio/sysvad/EndpointsCommon/speakerhptopo.cpp14
1 files changed, 8 insertions, 6 deletions
diff --git a/audio/sysvad/EndpointsCommon/speakerhptopo.cpp b/audio/sysvad/EndpointsCommon/speakerhptopo.cpp
index 76b82f13..1cd1d97b 100644
--- a/audio/sysvad/EndpointsCommon/speakerhptopo.cpp
+++ b/audio/sysvad/EndpointsCommon/speakerhptopo.cpp
@@ -245,16 +245,11 @@ Return Value:
DPF_ENTER(("[PropertyHandler_SpeakerHpTopoFilter]"));
// PropertryRequest structure is filled by portcls.
// MajorTarget is a pointer to miniport object for miniports.
//
NTSTATUS ntStatus = STATUS_INVALID_DEVICE_REQUEST;
-
- //
- // This line shows how to get a pointer to the miniport topology object.
- //
PCMiniportTopology pMiniport = (PCMiniportTopology)PropertyRequest->MajorTarget;
- UNREFERENCED_VAR(pMiniport);
if (IsEqualGUIDAligned(*PropertyRequest->PropertyItem->Set, KSPROPSETID_Jack))
{
@@ -267,6 +262,13 @@ Return Value:
ntStatus = PropertyHandler_SpeakerHpJackDescription2(PropertyRequest);
}
}
+ else if (IsEqualGUIDAligned(*PropertyRequest->PropertyItem->Set, KSPROPSETID_AudioResourceManagement))
+ {
+ if (PropertyRequest->PropertyItem->Id == KSPROPERTY_AUDIORESOURCEMANAGEMENT_RESOURCEGROUP)
+ {
+ ntStatus = pMiniport->PropertyHandlerAudioResourceGroup(PropertyRequest);
+ }
+ }
return ntStatus;
} // PropertyHandler_SpeakerHpTopoFilter
@@ -245,16 +245,11 @@ Return Value:
DPF_ENTER(("[PropertyHandler_SpeakerHpTopoFilter]"));
- // PropertryRequest structure is filled by portcls.
+ // PropertyRequest structure is filled by portcls.
// MajorTarget is a pointer to miniport object for miniports.
//